// Webclient Update Weather Underground
// Datei: buch3_kap10_webclient_wunderground.ino
// Datum: 04.06.14

#include <SPI.h>
#include <Ethernet.h>
#include "DHT.h"

// Ethernet-Konfiguration
byte mac[] = { 0xDE, 0xAD, 0xBE, 0xEF, 0xFE, 0xED };
byte ip[] = { 192, 168, 1, 222 };
byte gateway[] = { 192, 168, 1, 1 };
byte subnet[] = { 255, 255, 255, 0 };

// IP des externen Servers
IPAddress server(123, 44, 55, 100);

EthernetClient client;

long updateTimer;
boolean clientConnected = false;

// Data Pin 
#define DHTPIN 2 

// Auswahl Sensor Typ
//#define DHTTYPE DHT11   // DHT 11 
#define DHTTYPE DHT22   // DHT 22  (AM2302)
//#define DHTTYPE DHT21   // DHT 21 (AM2301)

// Sensor Objekt erstellen
DHT dht(DHTPIN, DHTTYPE);

float tempC;
float humOut;

void setup()
{
  Serial.begin(9600);
  Serial.println("Start...");
  dht.begin();
}

void loop()
{
  // Daten senden
  SendenDaten();
  // Status HTTP-Request einlesen
  checkStatus();
}

void SendenDaten()
{
  
  if ((millis() - updateTimer) > 60000)
  {
    // Messwerte einlesen
    // Temperatur
    tempC = dht.readTemperature();
    // Luftfeuchtigkeit
    humOut= dht.readHumidity();
    
    // Ethernet-Verbindung aufbauen
    Ethernet.begin(mac, ip);
    Serial.println("connecting...");
    delay(1000);
    if (client.connect(server, 80))
    {
      Serial.println("connected");
      client.print("GET /wunderground.php?t=");
      client.print(tempC);
      client.print("&h=");
      client.print(humOut);
      client.println(" HTTP/1.0");
      client.println("HOST:meinserver.com\n\n");
      client.println();
      client.println();
      clientConnected = true;
    }
    else
    {
	Serial.println("connection failed");
    }
    updateTimer = millis();
  }
}

void checkStatus()
{
  if (clientConnected)
  {
    if (client.available())
    {
	char c = client.read();
	Serial.print(c);
    }
    if (!client.connected())
    {
	Serial.println();
	Serial.println("disconnecting.");
	client.stop();
	clientConnected = false;
    }
  }
}
