//
// Roboter mit Wii Nunchuck steuern (Vorwärts, Rückwärts, Stop)
// Datei: buch3_kap6_roboter_mit_servo.ino
// Datum: 12.12.2014


#include <Servo.h>
#include <Wire.h>
#include "nunchuck_funcs.h"

int loop_cnt=0;
byte accx,accy,accz,zbut,cbut;
byte joyx, joyy;

// Servo Initialisierung
#define ServoPinLinks  10
#define ServoPinRechts  9

// Servo Objekte
Servo ServoLinks; 
Servo ServoRechts; 

// Servogeschwindigkeit 0-100 Prozent
int speed = 50;


void setup()
{
  Serial.begin(19200);
  nunchuck_setpowerpins();
  nunchuck_init(); // send the initilization handshake
  // Initialisierung Servos
  SetupRobot();
  delay(200);
}

void loop()
{
  if( loop_cnt > 100 )
  {
    loop_cnt = 0;
    nunchuck_get_data();
    
    // Beschleunigungssensor   
    accx  = nunchuck_accelx();
    accy  = nunchuck_accely();
    accz  = nunchuck_accelz();
    // Drucktasten
    zbut = nunchuck_zbutton();
    cbut = nunchuck_cbutton(); 
    // Joystick    
    joyx = nunchuck_joyx();
    joyy = nunchuck_joyy();
        
    // Joystick-Ausgabe auf seriellen Port
    Serial.print("Joystick-X: ");
    Serial.print((byte)joyx,DEC);
    Serial.print("  Joystick-Y: ");
    Serial.println((byte)joyy,DEC);
    
    // Servos ansteuern
    if (joyy > 200) 
    {
      ServoVor(); // vorwärts
    }  
    else
    {
      if (joyy < 30 )
      {
        ServoRueck(); // rückwärts
      }
      else
      {
        ServoStop(); // Stopp
      }
    }
  }
  loop_cnt++;
  delay(1);
}

// Roboter Funktionen

void SetupRobot()
{
  pinMode(ServoPinLinks, OUTPUT); 
  pinMode(ServoPinRechts, OUTPUT);
  ServoLinks.attach(ServoPinLinks);
  ServoRechts.attach(ServoPinRechts);
  ServoStop();
}

// Servo vorwärts
void ServoVor()
{
  ServoLinks.write(90 + speed);
  ServoRechts.write(90 - speed);
}

// Servo rückwärts
void ServoRueck()
{
  ServoLinks.write(90 - speed);
  ServoRechts.write(90 + speed);
}

// Servo stoppen
void ServoStop()
{
 ServoLinks.write(90);
 ServoRechts.write(90);
} 

// Servo links
void ServoLi(){
 ServoLinks.write(90 + speed);
 ServoRechts.write(90 + speed);
}

// Servo rechts
void ServoRe(){
 ServoLinks.write(90 - speed);
 ServoRechts.write(90 - speed);
}

